@@ -36,6 +36,10 @@ import (
 // AnnConfigAuthority is the annotation specifying a resource as the CDIConfig authority
 const (
 	AnnConfigAuthority = "cdi.kubevirt.io/configAuthority"
+	defaultCPULimit    = "750m"
+	defaultMemLimit    = "600M"
+	defaultCPURequest  = "100m"
+	defaultMemRequest  = "60M"
 )
 
 // CDIConfigReconciler members
@@ -223,13 +227,19 @@ func (r *CDIConfigReconciler) reconcileStorageClass(config *cdiv1.CDIConfig) err
 }
 
 func (r *CDIConfigReconciler) reconcileDefaultPodResourceRequirements(config *cdiv1.CDIConfig) error {
+	cpuLimit, _ := resource.ParseQuantity(defaultCPULimit)
+	memLimit, _ := resource.ParseQuantity(defaultMemLimit)
+	cpuRequest, _ := resource.ParseQuantity(defaultCPURequest)
+	memRequest, _ := resource.ParseQuantity(defaultMemRequest)
 	config.Status.DefaultPodResourceRequirements = &v1.ResourceRequirements{
 		Limits: map[v1.ResourceName]resource.Quantity{
-			v1.ResourceCPU:    *resource.NewQuantity(0, resource.DecimalSI),
-			v1.ResourceMemory: *resource.NewQuantity(0, resource.DecimalSI)},
+			v1.ResourceCPU:    cpuLimit,
+			v1.ResourceMemory: memLimit,
+		},
 		Requests: map[v1.ResourceName]resource.Quantity{
-			v1.ResourceCPU:    *resource.NewQuantity(0, resource.DecimalSI),
-			v1.ResourceMemory: *resource.NewQuantity(0, resource.DecimalSI)},
+			v1.ResourceCPU:    cpuRequest,
+			v1.ResourceMemory: memRequest,
+		},
 	}
 
 	if config.Spec.PodResourceRequirements != nil {
@@ -341,7 +351,6 @@ func (r *CDIConfigReconciler) createCDIConfig() (*cdiv1.CDIConfig, error) {
 }
 
 func (r *CDIConfigReconciler) reconcileImportProxy(config *cdiv1.CDIConfig) error {
-	log := r.log.WithName("CDIconfig").WithName("ImportProxyReconcile")
 	config.Status.ImportProxy = config.Spec.ImportProxy
 
 	// Avoid nil pointers and segfaults for the initial case, where ImportProxy is nil for both the spec and the status.
@@ -356,15 +365,17 @@ func (r *CDIConfigReconciler) reconcileImportProxy(config *cdiv1.CDIConfig) erro
 		// Try Openshift cluster wide proxy only if the CDIConfig default config is empty
 		clusterWideProxy, err := GetClusterWideProxy(r.client)
 		if err != nil {
-			log.V(3).Info(err.Error())
-			return nil
+			return err
 		}
 		config.Status.ImportProxy.HTTPProxy = &clusterWideProxy.Status.HTTPProxy
 		config.Status.ImportProxy.HTTPSProxy = &clusterWideProxy.Status.HTTPSProxy
 		config.Status.ImportProxy.NoProxy = &clusterWideProxy.Status.NoProxy
 		if clusterWideProxy.Spec.TrustedCA.Name != "" {
 			config.Status.ImportProxy.TrustedCAProxy = &clusterWideProxy.Spec.TrustedCA.Name
-			r.reconcileImportProxyCAConfigMap(config, clusterWideProxy)
+			err = r.reconcileImportProxyCAConfigMap(config, clusterWideProxy)
+			if err != nil {
+				return err
+			}
 		}
 	}
 	return nil
@@ -372,25 +383,26 @@ func (r *CDIConfigReconciler) reconcileImportProxy(config *cdiv1.CDIConfig) erro
 
 // Create/Update a configmap with the CA certificates in the controllor context with the cluster-wide proxy CA certificates to be used by the importer pod
 func (r *CDIConfigReconciler) reconcileImportProxyCAConfigMap(config *cdiv1.CDIConfig, proxy *ocpconfigv1.Proxy) error {
+	client := r.uncachedClient
 	cmName := proxy.Spec.TrustedCA.Name
 	if cmName == "" {
 		// Using the default cluster-wide proxy CA certificates configmap name
 		cmName = ClusterWideProxyConfigMapName
 	}
 	clusterWideProxyConfigMap := &v1.ConfigMap{}
-	if err := r.client.Get(context.TODO(), types.NamespacedName{Name: cmName, Namespace: ClusterWideProxyConfigMapNameSpace}, clusterWideProxyConfigMap); err == nil {
+	if err := client.Get(context.TODO(), types.NamespacedName{Name: cmName, Namespace: ClusterWideProxyConfigMapNameSpace}, clusterWideProxyConfigMap); err == nil {
 		// Copy the cluster-wide proxy CA certificates to the importer pod proxy CA certificates configMap
 		if certBytes, ok := clusterWideProxyConfigMap.Data[ClusterWideProxyConfigMapKey]; ok {
 			configMap := &v1.ConfigMap{}
-			if err := r.client.Get(context.TODO(), types.NamespacedName{Name: common.ImportProxyConfigMapName, Namespace: r.cdiNamespace}, configMap); errors.IsNotFound(err) {
-				if err := r.client.Create(context.TODO(), r.createProxyConfigMap(certBytes)); err != nil {
+			if err := client.Get(context.TODO(), types.NamespacedName{Name: common.ImportProxyConfigMapName, Namespace: r.cdiNamespace}, configMap); errors.IsNotFound(err) {
+				if err := client.Create(context.TODO(), r.createProxyConfigMap(certBytes)); err != nil {
 					return err
 				}
 				return nil
 			}
 			if configMap != nil {
 				configMap.Data[common.ImportProxyConfigMapKey] = certBytes
-				if err := r.client.Update(context.TODO(), configMap); err != nil {
+				if err := client.Update(context.TODO(), configMap); err != nil {
 					return err
 				}
 			}
