@@ -113,11 +113,11 @@ func convertToRaw(src, dest string, preallocate bool) error {
 	args := []string{"convert", "-t", "none", "-p", "-O", "raw", src, dest}
 	var err error
 	if preallocate {
-		err = addPreallocation(preallocate, args, convertPreallocationMethods, func(args []string) ([]byte, error) {
-			return qemuExecFunction(nil, nil, "qemu-img", args...)
+		err = addPreallocation(args, convertPreallocationMethods, func(args []string) ([]byte, error) {
+			return qemuExecFunction(nil, reportProgress, "qemu-img", args...)
 		})
 	} else {
-		_, err = qemuExecFunction(nil, nil, "qemu-img", args...)
+		_, err = qemuExecFunction(nil, reportProgress, "qemu-img", args...)
 	}
 	if err != nil {
 		os.Remove(dest)
@@ -128,29 +128,10 @@ func convertToRaw(src, dest string, preallocate bool) error {
 }
 
 func (o *qemuOperations) ConvertToRawStream(url *url.URL, dest string, preallocate bool) error {
-	if len(url.Scheme) == 0 {
-		// File, instead of URL
-		return convertToRaw(url.String(), dest, preallocate)
+	if len(url.Scheme) > 0 && url.Scheme != "nbd+unix" {
+		return fmt.Errorf("Not valid schema %s", url.Scheme)
 	}
-
-	jsonArg := fmt.Sprintf("json: {\"file.driver\": \"%s\", \"file.url\": \"%s\", \"file.timeout\": %d}", url.Scheme, url, networkTimeoutSecs)
-
-	var err error
-	args := []string{"convert", "-t", "none", "-p", "-O", "raw", jsonArg, dest}
-	if preallocate {
-		err = addPreallocation(preallocate, args, convertPreallocationMethods, func(args []string) ([]byte, error) {
-			return qemuExecFunction(nil, reportProgress, "qemu-img", args...)
-		})
-	} else {
-		_, err = qemuExecFunction(nil, reportProgress, "qemu-img", args...)
-	}
-	if err != nil {
-		// TODO: Determine what to do here, the conversion failed, and we need to clean up the mess, but we could be writing to a block device
-		os.Remove(dest)
-		return errors.Wrap(err, "could not stream/convert image to raw")
-	}
-
-	return nil
+	return convertToRaw(url.String(), dest, preallocate)
 }
 
 // convertQuantityToQemuSize translates a quantity string into a Qemu compatible string.
@@ -163,11 +144,16 @@ func convertQuantityToQemuSize(size resource.Quantity) string {
 	return strconv.FormatInt(int64Size, 10)
 }
 
+// Resize resizes the given image to size
+func Resize(image string, size resource.Quantity, preallocate bool) error {
+	return qemuIterface.Resize(image, size, preallocate)
+}
+
 func (o *qemuOperations) Resize(image string, size resource.Quantity, preallocate bool) error {
 	var err error
 	args := []string{"resize", "-f", "raw", image, convertQuantityToQemuSize(size)}
 	if preallocate {
-		err = addPreallocation(preallocate, args, resizePreallocationMethods, func(args []string) ([]byte, error) {
+		err = addPreallocation(args, resizePreallocationMethods, func(args []string) ([]byte, error) {
 			return qemuExecFunction(nil, nil, "qemu-img", args...)
 		})
 	} else {
@@ -179,56 +165,63 @@ func (o *qemuOperations) Resize(image string, size resource.Quantity, preallocat
 	return nil
 }
 
-func (o *qemuOperations) Info(url *url.URL) (*ImgInfo, error) {
-	var output []byte
-	var err error
-
-	if len(url.Scheme) > 0 {
-		// Image is a URL, make sure the timeout is long enough.
-		jsonArg := fmt.Sprintf("json: {\"file.driver\": \"%s\", \"file.url\": \"%s\", \"file.timeout\": %d}", url.Scheme, url, networkTimeoutSecs)
-		output, err = qemuExecFunction(qemuInfoLimits, nil, "qemu-img", "info", "--output=json", jsonArg)
-	} else {
-		output, err = qemuExecFunction(qemuInfoLimits, nil, "qemu-img", "info", "--output=json", url.String())
+func checkOutputQemuImgInfo(output []byte, image string) (*ImgInfo, error) {
+	var info ImgInfo
+	err := json.Unmarshal(output, &info)
+	if err != nil {
+		klog.Errorf("Invalid JSON:\n%s\n", string(output))
+		return nil, errors.Wrapf(err, "Invalid json for image %s", image)
 	}
+	return &info, nil
+
+}
+
+// Info returns information about the image from the url
+func Info(url *url.URL) (*ImgInfo, error) {
+	return qemuIterface.Info(url)
+}
+
+func (o *qemuOperations) Info(url *url.URL) (*ImgInfo, error) {
+	if len(url.Scheme) > 0 && url.Scheme != "nbd+unix" {
+		return nil, fmt.Errorf("Not valid schema %s", url.Scheme)
+	}
+	output, err := qemuExecFunction(qemuInfoLimits, nil, "qemu-img", "info", "--output=json", url.String())
 	if err != nil {
 		return nil, errors.Errorf("%s, %s", output, err.Error())
 	}
-	var info ImgInfo
-	err = json.Unmarshal(output, &info)
-	if err != nil {
-		klog.Errorf("Invalid JSON:\n%s\n", string(output))
-		return nil, errors.Wrapf(err, "Invalid json for image %s", url.String())
-	}
-	return &info, nil
+	return checkOutputQemuImgInfo(output, url.String())
 }
 
 func isSupportedFormat(value string) bool {
 	switch value {
-	case "raw", "qcow2":
+	case "raw", "qcow2", "vmdk", "vdi", "vpc", "vhdx":
 		return true
 	default:
 		return false
 	}
 }
 
+func checkIfURLIsValid(info *ImgInfo, availableSize int64, filesystemOverhead float64, image string) error {
+	if !isSupportedFormat(info.Format) {
+		return errors.Errorf("Invalid format %s for image %s", info.Format, image)
+	}
+
+	if len(info.BackingFile) > 0 {
+		return errors.Errorf("Image %s is invalid because it has backing file %s", image, info.BackingFile)
+	}
+
+	if int64(float64(availableSize)*(1-filesystemOverhead)) < info.VirtualSize {
+		return errors.Errorf("Virtual image size %d is larger than available size %d (PVC size %d, reserved overhead %f%%). A larger PVC is required.", info.VirtualSize, int64((1-filesystemOverhead)*float64(availableSize)), info.VirtualSize, filesystemOverhead)
+	}
+	return nil
+}
+
 func (o *qemuOperations) Validate(url *url.URL, availableSize int64, filesystemOverhead float64) error {
 	info, err := o.Info(url)
 	if err != nil {
 		return err
 	}
-
-	if !isSupportedFormat(info.Format) {
-		return errors.Errorf("Invalid format %s for image %s", info.Format, url.String())
-	}
-
-	if len(info.BackingFile) > 0 {
-		return errors.Errorf("Image %s is invalid because it has backing file %s", url.String(), info.BackingFile)
-	}
-
-	if int64(float64(availableSize)*(1-filesystemOverhead)) < info.VirtualSize {
-		return errors.Errorf("Virtual image size %d is larger than available size %d (PVC size %d, reserved overhead %f%%). A larger PVC is required.", info.VirtualSize, int64((1-filesystemOverhead)*float64(availableSize)), info.VirtualSize, filesystemOverhead)
-	}
-	return nil
+	return checkIfURLIsValid(info, availableSize, filesystemOverhead, url.String())
 }
 
 // ConvertToRawStream converts an http accessible image to raw format without locally caching the image
@@ -298,22 +291,21 @@ func PreallocateBlankBlock(dest string, size resource.Quantity) error {
 	return nil
 }
 
-func addPreallocation(preallocate bool, args []string, preallocationMethods [][]string, fn func(args []string) ([]byte, error)) error {
+func addPreallocation(args []string, preallocationMethods [][]string, qemuFn func(args []string) ([]byte, error)) error {
 	var err error
-	preallocationMethod := 0
-	for retry := true; retry; retry = err != nil && preallocationMethod < len(preallocationMethods) {
-		var argsToTry []string
+	for _, preallocationMethod := range preallocationMethods {
 		var output []byte
-		if preallocate {
-			klog.V(1).Info("Added preallocation")
-			// For some subcommands (e.g. resize), preallocation optinos must come before other options
-			argsToTry = append([]string{args[0]}, preallocationMethods[preallocationMethod]...)
-			argsToTry = append(argsToTry, args[1:]...)
-		}
-		output, err = fn(argsToTry)
+
+		klog.V(1).Infof("Adding preallocation method: %v", preallocationMethod)
+		// For some subcommands (e.g. resize), preallocation optinos must come before other options
+		argsToTry := append([]string{args[0]}, preallocationMethod...)
+		argsToTry = append(argsToTry, args[1:]...)
+
+		output, err = qemuFn(argsToTry)
 		if err != nil && strings.Contains(string(output), "Unsupported preallocation mode") {
-			preallocationMethod++
-			klog.V(1).Infof("Unsupported preallocation mode. Retrying with %s", preallocationMethods[preallocationMethod])
+			klog.V(1).Infof("Unsupported preallocation mode. Retrying")
+		} else {
+			break
 		}
 	}
 
